==> haskell-data-textual-0.3.0.3-457.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-data-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-textual
version:              0.3.0.3
visibility:           public
id:                   data-textual-0.3.0.3-LWd5CFCTedNKsLwqPW4jo8
key:                  data-textual-0.3.0.3-LWd5CFCTedNKsLwqPW4jo8
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-textual
synopsis:             Human-friendly textual representations.
description:
    This package provides an interface for converting between data and its
    (human-friendly) textual representation.

category:             Data, Text
abi:                  6787e86de29966ee2419a3523ca0c1ae
exposed:              True
exposed-modules:
    Data.Textual Data.Textual.Fractional Data.Textual.Integral

import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-textual-0.3.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-textual-0.3.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-textual-0.3.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-textual
hs-libraries:         HSdata-textual-0.3.0.3-LWd5CFCTedNKsLwqPW4jo8
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    parsers-0.12.12-1ZzbvPY4A605Mj7Pb7vKRT text-2.0.2
    text-latin1-0.3.1-9jgd1qX8NYS5SsYfvYOzxU
    text-printer-0.5.0.2-7dUulcQwVwPCJ4EFOY5An3

haddock-interfaces:
    /usr/share/doc/haskell-data-textual/html/data-textual.haddock

haddock-html:         /usr/share/doc/haskell-data-textual/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-textual-0.3.0.3-458-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-data-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-textual
version:              0.3.0.3
visibility:           public
id:                   data-textual-0.3.0.3-6Ou9Tf2REVc5yawnM2oba5
key:                  data-textual-0.3.0.3-6Ou9Tf2REVc5yawnM2oba5
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-textual
synopsis:             Human-friendly textual representations.
description:
    This package provides an interface for converting between data and its
    (human-friendly) textual representation.

category:             Data, Text
abi:                  51088107d649d3dbaa2f246e9b078aca
exposed:              True
exposed-modules:
    Data.Textual Data.Textual.Fractional Data.Textual.Integral

import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-textual-0.3.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-textual-0.3.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-textual-0.3.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-textual
hs-libraries:         HSdata-textual-0.3.0.3-6Ou9Tf2REVc5yawnM2oba5
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    parsers-0.12.12-PO1r5WusBRCqoNlSszPjk text-2.0.2
    text-latin1-0.3.1-69DBt6UpEUpH1mWnAZ6wlF
    text-printer-0.5.0.2-BYXc0vw9GxDJWKFuxOXvjc

haddock-interfaces:
    /usr/share/doc/haskell-data-textual/html/data-textual.haddock

haddock-html:         /usr/share/doc/haskell-data-textual/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
